#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
 * ------------------------------------------------------------------------
 * bmSearch
 * ------------------------------------------------------------------------
 * @license : GNU Affero General Public License Version 3 <http://www.gnu.org/licenses>
 * @author  : Pascal SALAUN 
 * @Website : http://www.bm-stats.org <http://www.bm-stats.org>
 * ------------------------------------------------------------------------
"""

# Native Python Lib/Class 
from collections import defaultdict
import json
import requests
import time


# bmSearch Class
from bmDate import *
import config


class requestToELK:
        """
        requestToELK:
                Class to send HTTP request (get/post) to an ELK platform
        """


        APIURL = config.APIURL

        def __init__(self):
                """
                __init__ :
                       Set default headers
                       Set a (dict) dates from bmDate
                """
                
                self.params = defaultdict(dict)
        
                self.headers = {'Content-Type': "application/json; charset=utf-8", 'Accept': "application/json"}
                self.params['headers'] = self.headers
                
                if hasattr(config,'user') and hasattr(config,'password'):
                        self.params['auth']    = []
                        self.params['auth'][0] = config.user
                        self.params['auth'][1] = config.password
                        
                if hasattr(config,'verifyPeer'):
                        self.params['verify'] = config.verifyPeer
                       
                        
                if hasattr(config,'serverCert'):
                         self.params['cert'] = config.serverCert

                        
                        
                
                
                """
                DATE
                """
                self.dates = bmDate().getDates()
               

		
        def setParam(self, **kwargs):
                """
                setParam:
                        overload params with these in **kwargs.
                        Params available are :
                            timeInterval
                        For details have a look in /etc/bmSearch/config.py
                """
                self.timeInterval = config.timeInterval
                if "timeInterval" in kwargs.keys():
                        self.timeInterval = kwargs['timeInterval']


                if "headers" in kwargs.keys():
                         self.params['headers'] = kwargs['headers']
                         
                if "user" in kwargs.keys():
                        try :
                                self.params['auth'][0] = kwargs['user']
                        except:
                                self.params['auth']    = []
                                self.params['auth'][0] = kwargs['user']
                        
                if "password" in kwargs.keys():
                        try :
                                self.params['auth'][1] = kwargs['password']
                        except:
                                self.params['auth']    = []
                                self.params['auth'][1] = kwargs['password']
                        
                        
                if "verifyPeer" in kwargs.keys():
                        self.params['verify'] = kwargs['verifyPeer']
                       
                        
                if "serverCert" in kwargs.keys():
                         self.params['cert'] = kwargs['serverCert']


        def sendData(self, data):
                """
                sendData :
                        Post (dict) data to an ELK platform
                        data have not to be JSON formated
                """
                
        	url = self.APIURL + "/bmsearch-" + self.dates['todayNumELK'] + "/message"
		self.params['json'] = data
        	try:
                	self.res = requests.post(url, **self.params)
                	
                except Exception as error:
    			pass



	def retrieveBmsearchId(self, msgid):
                """
                retrieveBmsearchId :
                        Try to retrieve Elasticsearch storage elements/informations (_id, _index and _type) from (str) msgid search request. 
                """
		self._id    = "" 
		self._type  = ""
		self._index = ""
	
		url = self.APIURL + "/bmsearch-*/_search"
		#dataS = dataS ='{"_source": "false", "query" : { "constant_score" : { "filter" : { "term" : { "msgid": "' + msgid + '" }}}}}'
		dataS='{ "_source": "false", "query": { "match_phrase": { "msgid": { "query": "' + msgid + '"}}}}'
		try:
			res = requests.post(url, dataS, **self.params).json()
	
			if res['hits']['total'] == 1 :
				header=dict(res['hits']['hits'][0])
				self._id    = header['_id']
				self._type  = header['_type']
				self._index = header['_index']
				
                except Exception as error:
    			pass


       
        def replaceDSNRecip(self, dataU):
               """
               replaceDSNRecip:
                        Try to update the Elasticsearch entry with data stored in dict dataU
               """
               if len(self._id) > 0 :
                        
                       
			if len(dataU['bouncedRecip']) or len(dataU['deferredRecip']):
				defList   = ', '.join(dataU['deferredRecip'])
				bounList  = ', '.join(dataU['bouncedRecip'])
				script    = '{ "script" : "ctx._source.deferredRecip = [\'' + defList  + '\']; ctx._source.bouncedRecip = [\'' + bounList  + '\']"}'

				url = self.APIURL + "/" + self._index + "/" + self._type + "/" + self._id  + "/_update"
                       
                        	try:
					r = requests.post(url, script, **self.params)
				
                		except Exception as error:
    					pass	
                       
                
                
        def updateDeliveredRecip(self, deliveredRecip):
                """
                updateDeliveredRecip :
                        Try to update an entry in Elasticsearch instance with (str) deliveredRecip var.
                        All elements needed for connection are taken from retrieveBmsearchId() called before.
                
                """
		
     		if len(self._id) > 0 :
	     		url = self.APIURL + "/" + self._index + "/" + self._type + "/" + self._id  + "/_update"
			dataU='{"script" : "if (ctx._source.containsKey(\'deliveredRecip\')) { ctx._source.deliveredRecip.add(\'' + deliveredRecip + '\') } else { ctx._source.deliveredRecip = [\'' + deliveredRecip + '\'] }"}'
			time.sleep(self.timeInterval)	
			try:
				r = requests.post(url, dataU, **self.params)
				
                	except Exception as error:
    				pass			
			
		

		
