#!/usr/bin/env python
# -*- coding: utf-8 -*-


"""
 * ------------------------------------------------------------------------
 * bmSearch
 * ------------------------------------------------------------------------
 * @license : GNU Affero General Public License Version 3 <http://www.gnu.org/licenses>
 * @author  : Pascal SALAUN 
 * @Website : http://www.bm-stats.org <http://www.bm-stats.org>
 * ------------------------------------------------------------------------
"""

import re

"""
#Postfix : these lines are about postfix activity for one mail  
"""        
## Get smtpd queueid on connection
#Aug 22 15:38:15 galadriel postfix/smtpd[29211]: 7E83C9E4318: client=.*
smtpdLine   = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/smtpd)\[(\d+)\]: (?P<queueid>.*): client=(?P<server>.*)(?:(, .*)+)?")

## Get message-id on receiving message
#Aug 22 20:09:21 galadriel postfix/cleanup[11415]: 6C54B9E433D: message-id=<20090822200921.9q4fg64u0wg4swkw@mail.mclabosse.fr>
cleanupLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/cleanup)\[(\d+)\]: (?P<queueid>.*): message-id=(?P<messageid>.*)")

## Get filename on trace line (cf postfix "main.cf" file) 
# Sep  5 10:16:10 galadriel postfix/cleanup[1302]: 6B1E32A87CE: warning: header Content-Type: image/png;? name="pascal.salaun_nbAtt_.png" from unknown[192.168.1.4]; \
#        from=<frodon.saquet@laposte.net> to=<frodon.saquet@laposte.net> proto=ESMTP helo=<[192.168.1.4]>: ThisFileName=pascal.salaun_nbAtt_.png
filenameLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/cleanup)\[(\d+)\]: (?P<queueid>.*): warning.*: ThisFileName=(?P<filename>.*)")

# Get Date field in body message
# Jul 31 18:31:43 bm35-debian8 postfix/cleanup[29323]: 9E8E940687: warning: header Date: Mon, 31 Jul 2017 18:31:43 +0200 from localhost[127.0.0.1]; from=<albert.einstein@bm35-debian8.intra> to=<ada.loveless@bm35-debian8.intra> proto=ESMTP helo=<localhost.localdomain>: bodyDate=Mon, 31 Jul 2017 18:31:43 +0200
bodyDateLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/cleanup)\[(\d+)\]: (?P<queueid>.*): warning.*: bodyDate=(?P<bodyDate>.*)")

# Get From field in body message
# Jul 31 18:31:43 bm35-debian8 postfix/cleanup[29323]: 9E8E940687: warning: header From: Albert EINSTEIN <albert.einstein@bm35-debian8.intra> from localhost[127.0.0.1]; from=<albert.einstein@bm35-debian8.intra> to=<ada.loveless@bm35-debian8.intra> proto=ESMTP helo=<localhost.localdomain>: bodyFrom=Albert EINSTEIN <albert.einstein@bm35-debian8.intra>
bodyFromLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/cleanup)\[(\d+)\]: (?P<queueid>.*): warning.*: bodyFrom=(?P<bodyFrom>.*)")

# Get Subject field in body message
# Jul 31 18:31:43 bm35-debian8 postfix/cleanup[29323]: 9E8E940687: warning: header Subject: Re: dsfsdf from localhost[127.0.0.1]; from=<albert.einstein@bm35-debian8.intra> to=<ada.loveless@bm35-debian8.intra> proto=ESMTP helo=<localhost.localdomain>: bodySubject=Re: dsfsdf
bodySubjectLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/cleanup)\[(\d+)\]: (?P<queueid>.*): warning.*: bodySubject=(?P<bodySubject>.*)")


## Get originator, volume and number of recip 
# Aug 22 15:38:15 galadriel postfix/qmgr[4158]: 7E83C9E4318: from=<frodon.saquet@laposte.net>, size=1767, nrcpt=1 (queue active)
qmgrLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/qmgr)\[(\d+)\]: (?P<queueid>.*): from=<(?P<from>.*)>, size=(?P<size>\d+), nrcpt=(?P<nrcpt>\d+).*")

## Get list of destinators (dsn=2.*.*)
# Apr  9 09:40:51 uruviel postfix/smtp[13879]: 22272341A57: to=<frodon.saquet@laposte.net>, relay=127.0.0.1[127.0.0.1]:10024, delay=7.6, delays=2.1/0.03/0.04/5.5, dsn=2.0.0, status=sent (250 2.0.0 from MTA(smtp:[127.0.0.1]:10025): 250 2.0.0 Ok: queued as 2004B341A80)
smtpLineDSN2 = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/)(.*)\[(\d+)\]: (?P<queueid>.*): to=<(?P<recip>.*?)(?:>, orig_to=<(?P<orig>.*?))?>, (.*)status=sent.*")

## Get list of deferred destinator (dsn=4.*.*)
smtpLineDSN4 = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/)(.*)\[(\d+)\]: (?P<queueid>.*): to=<(?P<recip>.*?)(?:>, orig_to=<(?P<orig>.*?))?>, (relay=.*)?(.*)status=deferred.*")

## Get list of deferred destinator (dsn=5.*.*)
smtpLineDSN5 = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/)(.*)\[(\d+)\]: (?P<queueid>.*): to=<(?P<recip>.*?)(?:>, orig_to=<(?P<orig>.*?))?>, (relay=.*)?(.*)status=bounced.*")        


## Get smtpd queueid before disconnection (file removed from spool)
# Apr 30 00:07:56 uruviel postfix/qmgr[4321]: 5141E341A1B: removed
smtpRemoved = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(postfix/qmgr)\[(\d+)\]: (?P<queueid>.*): removed")



"""
Cyrus/IMAP : this line is relative to a délivery success
"""
# Apr 30 02:49:38 uruviel cyrus/lmtp[20806]: Delivered: <20160409004835.40466.indimail@im19.nocalive.com> to mailbox: mclabosse.fr!user.pascal^salaun
cyrusDelivered = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(cyrus/lmtp.*)\[(\d+)\]: Delivered: (?P<messageid>.*) to mailbox: (?P<domain>.*)\!user.(?P<user>.*)")



"""
# Antivirus : these lines are relative to Antivirus status return stored in mail.log
"""        

## KLMS
#Jun  8 10:30:00 toto4 KLMS: clean: message-id="D2D75237B513CA42B5E59766133F55003F60695C@ex-mbx1.siege.grouponet.com": relay-ip="212.99.25.65": action="Skipped": rules="1": size=3458: mail-from="technique@toto.com": rcpt-to="pascal.salaun@mclabosse.fr": av-status="Clean", ap-status="Clean", as-status="Clean", cf-status="NotScanned, disabled by settings"
klmsLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) .* KLMS: (?P<status>.*): message-id=(?P<messageid>.*): relay.* av-status=(?P<avstatus>.*), ap-status=(?P<apstatus>.*), as-status=(?P<asstatus>.*),.*")


## Amavis
#Jul 19 15:10:13 uruviel amavis[17590]: (17590-18) Blocked BANNED (.exe,./postinst) {BouncedOutbound,Quarantined}, LOCAL [127.0.0.1]:57722 <pascal.salaun@mclabosse.fr> -> <technique@toto.com>, quarantine: R/banned-RtHNQLxoqL4r, Queue-ID: 25BBA222C2, Message-ID: <05ae29a5f9572ecc6d9de271f1186030@mclabosse.fr>, mail_id: RtHNQLxoqL4r, Hits: -, size: 820289, 2193 ms
amavisLine = re.compile(r"(?P<date>.{6}) (?P<hour>.{8}) (.*)(amavis)\[\d+\]: \((\d+)-(\d+)\) (?P<status>.*}), .*, Message-ID: <(?P<messageid>.*)>, .*")
