#!/bin/bash

# **
# * ------------------------------------------------------------------------
# * BlueMind Stats Portal, aka bm-stats
# * ------------------------------------------------------------------------
# * @license : GNU Affero General Public License Version 3 <http://www.gnu.org/licenses>
# * @author  : Pascal SALAUN 
# * @Website : http://bm-stats.org/ <http://bm-stats.org/>
# * ------------------------------------------------------------------------
# **

PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
export PATH

chmod 644 /etc/cron.d/bmSearch 
    
###  Check if bm-stats is already installed  ####
if [ -f "/usr/share/bm-stats/scripts/SHELL/MailLogRotate.sh" ] ; then
        echo "Oh, bm-stats is installed, thanks a lot !"
        echo " We are just disabling mail log rotation from bmSearch cron file"
        
        sed -i -e "s/\(.*#bmStatsAlreadyInstalled.*\)/#\1/" -e "/^#/s/#\{2,\}/#/g" /etc/cron.d/bmSearch

fi

### Setting Logs Management####
# which daemon (rsyslog|syslog-ng|sysklogd) 
DaemomLog=`yum -q list installed "*sys*log*" |sed 1d | tr -s " "|cut -d"." -f1`
	    
if [ "$DaemomLog" = "rsyslog" ]; then
	if [ -f /etc/logrotate.d/syslog ]; then
		echo "Configuring rsyslog and /etc/logrotate.d/rsyslog"
		sed -i 's/maillog/mail\.log/' /etc/rsyslog.conf
		mv /var/log/maillog /var/log/mail.log
		/etc/init.d/rsyslog restart
		sed -i '/maillog/d' /etc/logrotate.d/syslog
		echo "Restarting rsyslog..."
		etc/init.d/rsyslog restart
	fi
fi

if [ "$DaemomLog" = "syslog-ng" ]; then
	if [ -f /etc/logrotate.d/syslog ]; then
		echo "Configuring syslog-ng and /etc/logrotate.d/syslog-ng"
		sed -i '/maillog/d' /etc/logrotate.d/syslog
		sed -i 's/maillog/mail\.log/' /etc/syslog-ng/syslog-ng.conf
		sed -i 's/LogDaemon="rsyslog"/LogDaemon="syslog-ng"/' /usr/share/bmSearch/scripts/SHELL/MailLogRotate.sh
		echo "Restarting syslog-ng..."
		/etc/init.d/syslog-ng restart
	fi
fi

echo "A logrotate of mail.log file will now be done each day at 00:00, and the the filelog \"2 days old\" "
echo "will be moved in /var/log/mail/ ";

if [ -f "/usr/share/bm-stats/scripts/SHELL/MailLogRotate.sh" ] ; then
        echo "See /usr/share/bmSearch/scripts/SHELL/MailLogRotate.sh for details"
else
        echo "See /usr/share/bmSearch/scripts/SHELL/MailLogRotate.sh for details"
fi



checkIfPostfixInstalled=$(dpkg -l postfix |grep -c ^ii )
if [ "$checkIfPostfixInstalled" = "1" ] ; then
        echo "Checking postfix PCRE rules for bmStats/bmSearch" 

        reloadPostfix=0

        testPostfixMimeHeaderCkeck=$(grep -c -e '^mime_header.*BM_mime_header_checks' /etc/postfix/main.cf)

        if [ "$testPostfixMimeHeaderCkeck" = 0 ]; then

                reloadPostfix=1
                if [ ! -f "/etc/postfix/BM_mime_header_checks" ] ; then
                        cp /etc/postfix/BMSTATS/BM_mime_header_checks /etc/postfix/.
	
                        echo "Adding postfix MIME HEADER PCRE rules for bmSearch" 
		        echo "" >> /etc/postfix/main.cf
		        echo "#bmStats PCRE Rules" >> /etc/postfix/main.cf
		        echo "mime_header_checks= pcre:/etc/postfix/BM_mime_header_checks" >> /etc/postfix/main.cf

                fi
        fi

        testPostfixHeaderCkeck=$(grep -c -e '^header_checks.*' /etc/postfix/main.cf)

        if [ "$testPostfixMimeHeaderCkeck" = 1 ]; then

                testPostfixBMSEARCH_header_check=$(grep -c -e '^header_checks.*BMSEARCH_header_checks' /etc/postfix/main.cf)

                if [ "$testPostfixBMSEARCH_header_check" = 0 ]; then
                        reloadPostfix=1
                        echo "Adding postfix PCRE rules for bmSearch to already existing ones" 
                        sed -i"_"$(date +%Y%m%d-%H%M%S)"_by_bmSearch" '/^header_checks/s/\(.*\)/\1, pcre:\/etc\/postfix\/BMSEARCH_header_checks/' /etc/postfix/main.cf
                fi  


        else
                reloadPostfix=1
                echo "Adding postfix PCRE rules for bmSearch" 
                echo "header_checks= pcre:/etc/postfix/BMSEARCH_header_checks" >> /etc/postfix/main.cf

        fi

        if [ "$reloadPostfix" = "1" ]; then
                echo "Have to reload postfix"
                service postfix reload
        fi
fi

exit 0
